#
# spec file for package gummi
#
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           gummi
Version:        0.7.1
Release:        9.1
Summary:        Simple LaTeX editor
License:        MIT
Group:          Productivity/Publishing/TeX/Frontends
Url:            https://github.com/aitjcize/Gummi
# Upstream only provide tarballs from launchpad
Source0:        https://launchpad.net/~gummi/+archive/ubuntu/gummi/+files/%{name}-gtk3_%{version}.orig.tar.gz
# PATCH-FIX-UPSTREAM gummi-fix-crash-on-opening-file.patch bnc#840589 hpj@suse.com -- Fix crash on opening file from the GUI.
Patch1:         gummi-fix-crash-on-opening-file.patch
# PATCH-FIX-UPSTREAM gummi-predictable-tmpfiles.patch CVE-2015-7758 gh#alexandervdm/gummi#20 boo#949682 badshah400@gmail.com -- Fix predictable file names in /tmp; patch taken from debian patch tracker and submitted upstream
Patch2:         gummi-predictable-tmpfiles.patch
BuildRequires:  fdupes
BuildRequires:  intltool
BuildRequires:  pkg-config
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(gtksourceview-3.0)
BuildRequires:  pkgconfig(gtkspell3-3.0)
BuildRequires:  pkgconfig(poppler-glib)
Requires:       gtkspell
Requires:       texlive-latex
Recommends:     %{name}-lang
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Gummi is an opensource project that started in August of 2009 by
Alexander van der Mey. It is a LaTeX editor written in the C
programming language using the GTK+ toolkit. It was designed with
simplicity in mind, but hopes to attract both novice and advanced
LaTeX writers. Gummi is still under active development and is
released under the opensource MIT license.

%lang_package

%prep
%setup -q -n %{name}-gtk3-%{version}
%patch1 -p1
%patch2 -p1

%build
%configure
make %{?_smp_mflags}

%install
make install DESTDIR=%{buildroot} INSTALL="install -p"
%find_lang %{name}
%suse_update_desktop_file %{name} Office WordProcessor
%fdupes %{buildroot}%{_datadir}/

%files
%defattr(-,root,root,-)
%doc AUTHORS ChangeLog COPYING README
%{_mandir}/man*/*.1*
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.png
%{_datadir}/%{name}/
%{_libdir}/%{name}/

%files lang -f %{name}.lang

%changelog
* Wed Feb 17 2016 badshah400@gmail.com
- Update gummi-predictable-tmpfiles.patch with final patch
  committed by upstream (CVE-2015-7758, gh#alexandervdm/gummi#20,
  boo#949682).
* Thu Dec 17 2015 badshah400@gmail.com
- Add patch gummi-predictable-tmpfiles.patch to fix an exploitable
  issue caused by gummi setting predictable file names in /tmp;
  patch taken from debian patch tracker and submitted upstream
  (CVE-2015-7758, gh#alexandervdm/gummi#20, boo#949682).
* Fri Jan 16 2015 p.drouand@gmail.com
- Update to version 0.7.1
  + No changelog entry
- Move to GTK3
  + Replace pkgconfig(gtk+-2.0) with pkgconfig(gtk+-3.0)
  + Replace pkgconfig(gtksourceview-2.0) with pkgconfig(gtksourceview-3.0)
  + Replace pkgconfig(gtkspell-2.0) with pkgconfig(gtkspell3-3.0)
- Update Url; point to new home of the project
- Remove gummi-deprecated-g_thread_init.patch; fixed on upstream
- Adapt gummi-fix-crash-on-opening-file.patch to upstream changes
- Use download Url as source
- Split out translation files into a -lang subpackage
* Fri Sep 27 2013 hpj@suse.com
- Add gummi-fix-crash-on-opening-file.patch (bnc#840589,
  http://dev.midnightcoding.org/issues/498 ).
* Wed Jan 30 2013 badshah400@gmail.com
- Update to version 0.6.5:
  + Bugs fixed:
  - Fixed empty build logs when special characters were included
  - Fixed a rare deadlock situation on program exit
  - Fixed regression in spell-checking language listing
  - Fixed regression in killing inresponsive compilation
    processes
  - Correctly close file descriptors for child processes
  - Implemented --version CLI argument
  - Several translation updates
  - Added Hungarian translation
- Minor rebase of patch gummi-deprecated-g_thread_init.patch.
* Mon Jun 25 2012 badshah400@gmail.com
- Update to version 0.6.4:
  + Bugs fixed:
  - Replaced faulty importer implementation with a toolbar
    variant
  - Fixed an issue where the previewer would not display
    correctly
  - dvi script uses exit status to signal compilation status
  - Improved the reported messages for some errors.
  - Better TeXLive version detection
  - Fixed a reference problem that could lead to a crash
  - Search window is correctly centered in GNOME 3
  - Tab markup not enabled when project loading fails
  - Minor UI tweaks to the project & bibliography panels
  - Minor UI tweaks to the snippet configuration interface
  + Minor rebase of patch gummi-deprecated-g_thread_init.patch.
* Tue Apr  3 2012 badshah400@gmail.com
- Update to version 0.6.3:
  + Bugs fixed:
  - Fix bibtex regression since 0.6.2
  - Fix for compiling through dvi/ps
  - Correctly disable template open button when none exist
  - Gummi toolbar can be hidden again
  - Fix LaTeX error screen and error line output
  - Menu item compatibility with Ubuntu's Unity fixed
  - Added Chinese (simplified) translation.
- Changes from version 0.6.2:
  + Bugs fixed:
  - Recovery mode is also triggered when gummi is run with file
    argv
  - Incomplete compilation processes are killed on tab switch
  - Fix template addition crash when zero tabs are opened
  - PDF files can now be used by the image importer
  - Fixed building/compilation scripts for explicit linking
  - Default text only written to disk when changes are made
  - SyncTeX auto-scrolling is now disabled by default
  - Converted snippet offsets to utf8
  - Bibliography items with all capital letters can be parsed
  - Various minor spelling/phrasing errors
  - Build files can now be removed from the menu
  - Lots of Windows specific issues
  - Addition of user guide link.
* Tue Feb 14 2012 badshah400@gmail.com
- Add gummi-deprecated-g_thread_init.patch to fix build failures
  for openSUSE > 12.1
* Tue Dec 13 2011 badshah400@gmail.com
- Upgrade to version 0.6.1:
  + Bugs fixed:
  - Selecting text no longer freezes during updates
  - Shell escape option is now set/unset correctly
  - Fixed crash when trying to open non-existing file from cli
  - Popup windows no longer block gui in fullscreen mode
  - Documents containing input commands can pass precompile
    check
  - Opening snippet menu no longer blocks gui
  - Several fixes to snippet insertion mechanism
  - Minor tweaks to the build scripts for convenience
  - Fixed some minor memory leaks
- Changes from version 0.6.0:
  + Features added:
  - Multi-tab/document support
  - LaTeX build systems (rubber/latexmk)
  - Compiling through DVI/Postscript
  - Continuous PDF preview
  - Filter function for bibliographies
  - Improved document statistics
  - Infoscreen panel with document status
  - More configurable options
  - Minimal project support
  - SyncTeX support
  - New & updated translations
  + Bugs fixed:
  - Improved preview scaling performance
  - Importer file choosers now default to CWD
  - Fixed image import warning
  - Fixed rare segfault on gummi start
  - Search results colour depends on color theme
  - Preview scroll position restored after error
  - Replaced all win32 incompatible code
  - Configuration I/O transaction fixes
  - Modifier keys no longer trigger auto-compile
  - Correct encoded text is written on file save
  - Fixed a rare GUI hang when program is closed
  - Several GUI and icon related problems
  - Several memory leaks
